Django Suit documentation — Django Suit 0.2.21 documentation

# Django Suit documentation

Django Suit - Modern theme for Django admin interface.

## About

Django Suit is alternative theme/skin/extension for Django admin app (administration interface).

## Licence

- Django Suit is licensed under Creative Commons Attribution-NonCommercial 3.0 license.
- See licence and pricing: http://djangosuit.com/pricing/

## Resources

- Home page: http://djangosuit.com
- Demo: http://djangosuit.com/admin/
- Licence and Pricing: http://djangosuit.com/pricing/
- Github: https://github.com/darklow/django-suit
- Demo app on Github: https://github.com/darklow/django-suit-examples
- Changelog: Changelog.rst
- Supports: Django 1.4-1.10. Python: 2.6-3.4
- Supported apps

## Preview

Click on screenshot for live demo:

# Getting Started

- Getting Started
  - Installation
  - Deployment
  - Develop branch
  - v2-dev branch
- Configuration
  - Templates
  - Customization
  - Full example
  - Header
  - Forms
  - Menu
  - List

# Features

## Widgets

There are handy widgets included in Django Suit.

- Widgets
  - NumberInput
  - HTML5Input
  - EnclosedInput
  - AutosizedTextarea
  - Date/Time widgets
  - LinkedSelect

## Sortables

Sortables are handy admin tools for ordering different lists.

- Sortables
  - Limitations
  - Under the hood
  - Change list sortable
    - Example
    - Resources
  - django-mptt tree sortable
    - Example
    - Resources
  - Tabular inlines sortable
    - Example
    - Resources
  - Stacked and Generic inlines sortable
    - Example
    - Resources

## Form tabs

Form tabs help you organize form fieldsets and inlines into tabs.

- Form tabs

## Form includes

Django Suit provides handy shortcut to include templates into forms.

- Form Includes
  - Example
  - Preview

## List attributes

Using few callable helpers you can customize change list row and cell attributes based on object instance variables.

- List attributes
  - List header columns
  - List row attributes
  - List cell attributes

## Wysiwyg editors

How to use wysiwyg editors in Django Suit.

- WYSIWYG editors
  - Imperavi Redactor
  - CKEditor 4.x
  - Other wysiwyg apps

## JavaScript and CSS

- JavaScript & CSS
  - JavaScript goodies
    - Inlines hook
    - jQuery
  - CSS goodies

# Support

- Github: Use django-suit github issues, if you have any problems using Django Suit.

## Examples

Besides documentation examples, Django Suit demo application source code is also available on separate github repository: django-suit-examples. If you see anything in demo application, you can always go to this repository and see implementation and code in one of `models.py` or `admin.py` files

## Supported apps

Besides Django admin, Django Suit supports following third-party apps:

- django-cms (v2.3.5 - v2.4.3) - Example Read notes
- django-filer (since v0.9.4) - Example
- django-mptt - Example
- django-reversion - Example
- django-import-export - Example
- Suggest other popular apps you would like to be supported here

Important

If you are using third-party apps with special admin support (like django-cms) you also need to add `'suit'` before `'cms'` in the list of ``INSTALLED_APPS`` in your ``settings.py`` file.

# Contributing

- Contributing
  - Tests
  - CSS/LESS
  - Related packages